package com.zjsgfa.project.zjsgfa.mapper;

import java.util.List;

import com.zjsgfa.project.zjsgfa.domain.SjZlyqZbyq;

/**
 * 设计信息-中靶要求-定向井Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-17
 */
public interface SjZlyqZbyqMapper 
{
    /**
     * 查询设计信息-中靶要求-定向井
     * 
     * @param id 设计信息-中靶要求-定向井主键
     * @return 设计信息-中靶要求-定向井
     */
    public SjZlyqZbyq selectSjZlyqZbyqById(Long id);

    /**
     * 查询设计信息-中靶要求-定向井列表
     * 
     * @param sjZlyqZbyq 设计信息-中靶要求-定向井
     * @return 设计信息-中靶要求-定向井集合
     */
    public List<SjZlyqZbyq> selectSjZlyqZbyqList(SjZlyqZbyq sjZlyqZbyq);

    /**
     * 新增设计信息-中靶要求-定向井
     * 
     * @param sjZlyqZbyq 设计信息-中靶要求-定向井
     * @return 结果
     */
    public int insertSjZlyqZbyq(SjZlyqZbyq sjZlyqZbyq);

    /**
     * 修改设计信息-中靶要求-定向井
     * 
     * @param sjZlyqZbyq 设计信息-中靶要求-定向井
     * @return 结果
     */
    public int updateSjZlyqZbyq(SjZlyqZbyq sjZlyqZbyq);

    /**
     * 删除设计信息-中靶要求-定向井
     * 
     * @param id 设计信息-中靶要求-定向井主键
     * @return 结果
     */
    public int deleteSjZlyqZbyqById(Long id);

    /**
     * 批量删除设计信息-中靶要求-定向井
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSjZlyqZbyqByIds(Long[] ids);

    int deleteSjZlyqZbyqByJh(String jh);

    int insertSjZlyqZbyqBatch(List<SjZlyqZbyq> sjZlyqZbyqList);

}
